$ zzmaiores | sed '/clitest/d' | head -n 9 | cut -f 2
zznumero.sh
zzdatafmt.sh
zzansi2html.out.html
zztimer.sh
zztestar.sh
zzf1.sh
zzdata.sh
zzconjugar.sh
zzascii.sh
$
